"""
Module for managing a DTP 5010 remote value.

DPT 5.010.
"""
from __future__ import annotations

from xknx.dpt import DPTArray, DPTBinary, DPTValue1Ucount
from xknx.exceptions import CouldNotParseTelegram

from .remote_value import RemoteValue


class RemoteValueDptValue1Ucount(RemoteValue[DPTArray, int]):
    """Abstraction for remote value of KNX DPT 5.010."""

    def payload_valid(self, payload: DPTArray | DPTBinary | None) -> DPTArray:
        """Test if telegram payload may be parsed."""
        if isinstance(payload, DPTArray) and len(payload.value) == 1:
            return payload
        raise CouldNotParseTelegram("Payload invalid", payload=str(payload))

    def to_knx(self, value: int) -> DPTArray:
        """Convert value to payload."""
        return DPTArray(DPTValue1Ucount.to_knx(value))

    def from_knx(self, payload: DPTArray) -> int:
        """Convert current payload to value."""
        return DPTValue1Ucount.from_knx(payload.value)



"""Classes for handling KNX IP Secure."""
from .keyring import Keyring, load_key_ring
from .util import bytes_xor, sha256_hash

__all__ = [
    "Keyring",
    "load_key_ring",
    "bytes_xor",
    "sha256_hash",
]



"""Module for XKNX Exception handling."""
# flake8: noqa
from .exception import (
    CommunicationError,
    ConversionError,
    CouldNotParseAddress,
    CouldNotParseKNXIP,
    CouldNotParseTelegram,
    DeviceIllegalValue,
    IncompleteKNXIPFrame,
    InterfaceWithUserIdNotFound,
    InvalidSecureConfiguration,
    InvalidSignature,
    KNXSecureValidationError,
    SecureException,
    UnsupportedCEMIMessage,
    XKNXException,
)

__all__ = [
    "CommunicationError",
    "ConversionError",
    "CouldNotParseAddress",
    "CouldNotParseKNXIP",
    "CouldNotParseTelegram",
    "DeviceIllegalValue",
    "IncompleteKNXIPFrame",
    "InterfaceWithUserIdNotFound",
    "InvalidSecureConfiguration",
    "InvalidSignature",
    "KNXSecureValidationError",
    "SecureException",
    "UnsupportedCEMIMessage",
    "XKNXException",
]



"""KNX Constants used within io."""

DEFAULT_MCAST_GRP = "224.0.23.12"
DEFAULT_MCAST_PORT = 3671

CONNECTION_ALIVE_TIME = 120
CONNECTIONSTATE_REQUEST_TIMEOUT = 10
HEARTBEAT_RATE = CONNECTION_ALIVE_TIME - (CONNECTIONSTATE_REQUEST_TIMEOUT * 5)

# Maximum time an authenticated secure session may remain unused (without
# any communication over this session) until the session will be dropped.
SESSION_TIMEOUT = 60
SESSION_KEEPALIVE_RATE = SESSION_TIMEOUT - 10
XKNX_SERIAL_NUMBER = bytes.fromhex("00 00 78 6b 6e 78")
